SELECT 'CREATE INDEX for xml_path.pathexp' as phase1;
CREATE INDEX "xml_path_exp" ON "xml_path" USING BTREE ( "pathexp" );

SELECT 'DROP INDEX xml_node_next' as phase2;
DROP INDEX "xml_node_next";

-- if repository is a static.
SELECT 'CREATE INDEX for xml_node_dewey' as phase3;
REINDEX INDEX "xml_node_dewey";
--CREATE INDEX xml_node_dewey ON xml_node USING btree(dewey intarray_abs_ops);

VACUUM ANALYZE;
